@@ -1,4 +1,3 @@
-from django.conf import settings
 from django.db import models
 from edc_model.models import BaseUuidModel
 from edc_utils import get_utcnow
@@ -8,10 +7,6 @@ from edc_crf.model_mixins import CrfModelMixin, CrfStatusModelMixin
 
 class Crf(CrfModelMixin, CrfStatusModelMixin, BaseUuidModel):
 
-    subject_visit = models.ForeignKey(settings.SUBJECT_VISIT_MODEL, on_delete=models.PROTECT)
-
-    report_datetime = models.DateTimeField(default=get_utcnow)
-
     f1 = models.CharField(max_length=50, null=True, blank=True)
 
     f2 = models.CharField(max_length=50, null=True, blank=True)
@@ -20,3 +15,23 @@ class Crf(CrfModelMixin, CrfStatusModelMixin, BaseUuidModel):
 
     class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
         pass
+
+
+class CrfReportDatetimeNotRequired(CrfModelMixin, CrfStatusModelMixin, BaseUuidModel):
+
+    report_datetime = models.DateTimeField(default=get_utcnow, null=True, blank=True)
+
+    f1 = models.CharField(max_length=50, null=True, blank=True)
+
+    f2 = models.CharField(max_length=50, null=True, blank=True)
+
+    f3 = models.CharField(max_length=50, null=True, blank=True)
+
+    def update_reference_on_save(self):
+        pass
+
+    def metadata_update(self):
+        pass
+
+    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
+        pass
